maybe_attach_sponsor

Function maybe_attach_sponsor 

pub(crate) async fn maybe_attach_sponsor<N, P>(
    sponsor: Option<&TempoSponsor>,
    provider: Option<&P>,
    chain: Chain,
    tx: &mut N::TransactionRequest,
    payer: Address,
) -> Result<()>
where N: Network, N::TransactionRequest: Default + FoundryTransactionBuilder<N>, P: Provider<N>,
Resolves the sponsored fee token and attaches the sponsor signature preview for payer when a sponsor is configured.