pub(crate) fn tempo_provider(
opts: &impl LoadConfig,
) -> Result<(Config, RetryProvider<TempoNetwork>)>Expand description
Loads the config for opts and builds a Tempo provider from it.
pub(crate) fn tempo_provider(
opts: &impl LoadConfig,
) -> Result<(Config, RetryProvider<TempoNetwork>)>Loads the config for opts and builds a Tempo provider from it.